@@ -171,10 +171,8 @@ class FlaskS3(object):
     :type app: :class:`flask.Flask` or None
     """
     def __init__(self, app=None):
-        self.app = None
         if app is not None:
-            self.app = app
-            self.init_app(self.app)
+            self.init_app(app)
 
     def init_app(self, app):
         """
